@@ -3,9 +3,10 @@
 """Functional tests for tvnamer tests
 """
 
+import os
 from functional_runner import run_tvnamer, verify_out_data
-from nose.plugins.attrib import attr
-from helpers import expected_failure_travisci
+from helpers import attr
+import pytest
 
 
 @attr("functional")
@@ -64,15 +65,13 @@ def test_simple_batch_functionality():
 
     for curtest in tests:
 
-        def _the_test():
-            out_data = run_tvnamer(
-                with_files = [curtest['in'], ],
-                with_flags = ['--batch'],
-            )
-            verify_out_data(out_data, [curtest['expected'], ])
-
-        _the_test.description = "test_simple_functionality_%s" % curtest['in']
-        yield _the_test
+        print("Expecting %r to turn into %r" % (
+            curtest['in'], curtest['expected']))
+        out_data = run_tvnamer(
+            with_files = [curtest['in'], ],
+            with_flags = ['--batch'],
+        )
+        verify_out_data(out_data, [curtest['expected'], ])
 
 
 @attr("functional")
@@ -101,10 +100,17 @@ def test_interactive_always_option():
 
 
 @attr("functional")
-@expected_failure_travisci
+@pytest.mark.skipif(os.getenv("TRAVIS", "false")=="true", reason="Test fails for some reason on Travis-CI")
 def test_unicode_in_inputname():
     """Tests parsing a file with unicode in the input filename
     """
+
+    import os, sys
+    if os.getenv("TRAVIS", "false") == "true" and sys.version_info[0:2] == (2.6):
+        from nose.plugins.skip import SkipTest
+        raise SkipTest("Ignoring test which triggers bizarre bug in nosetests, in python 2.6, only on travis.")
+
+
     input_files = [
         u'The Big Bang Theory - S02E07 - The Panty Pin\u0303ata Polarization.avi']
 
@@ -155,10 +161,10 @@ def test_renaming_always_doesnt_overwrite():
 
 
 @attr("functional")
+@pytest.mark.skipif(os.getenv("TRAVIS", "false")=="true", reason="Test fails for some reason on Travis-CI")
 def test_not_overwritting_unicode_filename():
     """Test no error occurs when warning about a unicode filename being overwritten
     """
-    return
     input_files = [
         u'The Big Bang Theory - S02E07.avi',
         u'The Big Bang Theory - [02x07] - The Panty Pin\u0303ata Polarization.avi']
@@ -264,3 +270,32 @@ def test_skipping_after_replacements():
     expected_files = ['Scrvbs - [01x01] - My First Day.avi']
 
     verify_out_data(out_data, expected_files)
+
+@attr("functional")
+def test_dvd_order():
+    """Tests TvDB dvd order naming
+    """
+
+    input_files = [
+        'batman the animated series s01e01.xvid']
+
+    expected_files = [
+        'Batman - The Animated Series - [01x01] - On Leather Wings.xvid']
+
+    conf = r"""
+    {
+      "output_filename_replacements": [
+        {"is_regex": true,
+        "match": ": ",
+        "replacement": " - "}
+      ]
+    }
+    """
+
+    out_data = run_tvnamer(
+        with_files = input_files,
+        with_flags = ["--order", 'dvd'],
+        with_input = "1\ny\n",
+        with_config = conf)
+
+    verify_out_data(out_data, expected_files)
